@@ -142,8 +142,8 @@ QString XdgBaseDirs::findResourceFile( const char *resource, const QString &relP
 
   QStringList pathList = systemPathList( resource );
 
-  QStringList::const_iterator it    = pathList.begin();
-  QStringList::const_iterator endIt = pathList.end();
+  QStringList::const_iterator it    = pathList.constBegin();
+  QStringList::const_iterator endIt = pathList.constEnd();
   for ( ; it != endIt; ++it ) {
     fileInfo = QFileInfo( *it + QLatin1Char('/' ) + relPath );
     if ( fileInfo.exists() && fileInfo.isFile() && fileInfo.isReadable() ) {
@@ -154,7 +154,7 @@ QString XdgBaseDirs::findResourceFile( const char *resource, const QString &relP
   return QString();
 }
 
-QString XdgBaseDirs::findExecutableFile( const QString &relPath )
+QString XdgBaseDirs::findExecutableFile( const QString &relPath, const QStringList &searchPath )
 {
   if ( instance()->mExecutableDirs.isEmpty() ) {
     QStringList executableDirs = instance()->systemPathList( "PATH", "/usr/local/bin:/usr/bin" );
@@ -164,16 +164,18 @@ QString XdgBaseDirs::findExecutableFile( const QString &relPath )
       executableDirs << prefixExecutableDir;
     }
 
+    executableDirs += searchPath;
+
     instance()->mExecutableDirs = executableDirs;
   }
 
-  QStringList::const_iterator pathIt    = instance()->mExecutableDirs.begin();
-  QStringList::const_iterator pathEndIt = instance()->mExecutableDirs.end();
+  QStringList::const_iterator pathIt    = instance()->mExecutableDirs.constBegin();
+  QStringList::const_iterator pathEndIt = instance()->mExecutableDirs.constEnd();
   for ( ; pathIt != pathEndIt; ++pathIt ) {
     QStringList fullPathList = alternateExecPaths(*pathIt + QLatin1Char( '/' ) + relPath );
 
-    QStringList::const_iterator it    = fullPathList.begin();
-    QStringList::const_iterator endIt = fullPathList.end();
+    QStringList::const_iterator it    = fullPathList.constBegin();
+    QStringList::const_iterator endIt = fullPathList.constEnd();
     for ( ; it != endIt; ++it ) {
       QFileInfo fileInfo(*it);
 
@@ -197,8 +199,8 @@ QString XdgBaseDirs::findResourceDir( const char *resource, const QString &relPa
 
   QStringList pathList = systemPathList( resource );
 
-  QStringList::const_iterator it    = pathList.begin();
-  QStringList::const_iterator endIt = pathList.end();
+  QStringList::const_iterator it    = pathList.constBegin();
+  QStringList::const_iterator endIt = pathList.constEnd();
   for ( ; it != endIt; ++it ) {
     fileInfo = QFileInfo( *it + QLatin1Char('/' ) + relPath );
     if ( fileInfo.exists() && fileInfo.isDir() && fileInfo.isReadable() ) {
@@ -222,8 +224,8 @@ QStringList XdgBaseDirs::findAllResourceDirs( const char *resource, const QStrin
 
   QStringList pathList = systemPathList( resource );
 
-  QStringList::const_iterator it    = pathList.begin();
-  QStringList::const_iterator endIt = pathList.end();
+  QStringList::const_iterator it    = pathList.constBegin();
+  QStringList::const_iterator endIt = pathList.constEnd();
   for ( ; it != endIt; ++it ) {
     fileInfo = QFileInfo( *it + QLatin1Char('/' ) + relPath );
     if ( fileInfo.exists() && fileInfo.isDir() && fileInfo.isReadable() ) {
