@@ -51,11 +51,16 @@ bool Akonadi::AkAppend::handleLine(const QByteArray& line )
     //        (partname literal)+
     //
     // Syntax:
-    // x-akappend = "X-AKAPPEND" SP mailbox [SP flag-list] [SP date-time] SP (partname SP literal)+
+    // x-akappend = "X-AKAPPEND" SP mailbox SP size [SP flag-list] [SP date-time] SP (partname SP literal)+
 
     const int startOfCommand = line.indexOf( ' ' ) + 1;
     const int startOfMailbox = line.indexOf( ' ', startOfCommand ) + 1;
-    const int startOfFlags = ImapParser::parseString( line, m_mailbox, startOfMailbox ) + 1;
+
+    const int startOfSize = ImapParser::parseString( line, m_mailbox, startOfMailbox ) + 1;
+
+    QString size;
+    const int startOfFlags = ImapParser::parseString( line, size, startOfSize ) + 1;
+    m_size = size.toLongLong();
 
     // parse optional flag parenthesized list
     // Syntax:
@@ -69,7 +74,6 @@ bool Akonadi::AkAppend::handleLine(const QByteArray& line )
     if ( line[startOfFlags] == '(' ) {
         startOfDateTime = ImapParser::parseParenthesizedList( line, m_flags, startOfFlags ) + 1;
     }
-    m_flags.append( "\\Recent" ); // the Recent flag always has to be set
 
     // parse optional date/time string
     int startOfPartSpec = startOfDateTime;
@@ -160,6 +164,7 @@ bool Akonadi::AkAppend::commit()
 
     PimItem item;
     item.setRev( 0 );
+    item.setSize( m_size );
 
     bool ok = db->appendPimItem( m_parts, mimeType, l, m_dateTime, remote_id, item );
 
