@@ -30,6 +30,7 @@
 #include "storage/transaction.h"
 
 #include <QtCore/QDebug>
+#include <QLocale>
 
 using namespace Akonadi;
 
@@ -51,11 +52,20 @@ bool Akonadi::Append::handleLine(const QByteArray& line )
     //        message literal
     //
     // Syntax:
-    // append = "APPEND" SP mailbox [SP flag-list] [SP date-time] SP literal
+    // append = "APPEND" SP mailbox SP size [SP flag-list] [SP date-time] SP literal
 
     const int startOfCommand = line.indexOf( ' ' ) + 1;
     const int startOfMailbox = line.indexOf( ' ', startOfCommand ) + 1;
-    const int startOfFlags = ImapParser::parseString( line, m_mailbox, startOfMailbox ) + 1;
+
+    const int startOfSize = ImapParser::parseString( line, m_mailbox, startOfMailbox ) + 1;
+
+    QString size;
+    const int startOfFlags = ImapParser::parseString( line, size, startOfSize ) + 1;
+    m_size = size.toLongLong();
+
+    QString data;
+    ImapParser::parseString( line, data, startOfSize);
+    m_size = data.toLongLong();
 
     // parse optional flag parenthesized list
     // Syntax:
@@ -69,16 +79,18 @@ bool Akonadi::Append::handleLine(const QByteArray& line )
     if ( line[startOfFlags] == '(' ) {
         startOfDateTime = ImapParser::parseParenthesizedList( line, m_flags, startOfFlags ) + 1;
     }
-    m_flags.append( "\\Recent" ); // the Recent flag always has to be set
 
     // parse optional date/time string
     int startOfLiteral = startOfDateTime;
     if ( line[startOfDateTime] == '"' ) {
         startOfLiteral = ImapParser::parseDateTime( line, m_dateTime, startOfDateTime );
+        m_dateTime = m_dateTime.toUTC();
         // FIXME Should we return an error if m_dateTime is invalid?
+    } else {
+        // if date/time is not given then it will be set to the current date/time
+        // converted to UTC.
+        m_dateTime = QDateTime::currentDateTime().toUTC();
     }
-    // if date/time is not given then it will be set to the current date/time
-    // by the database
 
     ImapParser::parseString( line, m_data, startOfLiteral );
     return commit();
@@ -116,8 +128,11 @@ bool Akonadi::Append::commit()
     if ( !mimeType.isValid() ) {
       return failureResponse( QString::fromLatin1( "Unknown mime type '%1'.").arg( QString::fromLatin1( mt ) ) );
     }
+
     PimItem item;
     item.setRev( 0 );
+    item.setSize( m_size );
+    item.setDatetime( m_dateTime );
 
     // wrap data into a part
     Part part;
@@ -144,9 +159,16 @@ bool Akonadi::Append::commit()
     if ( !transaction.commit() )
         return failureResponse( "Unable to commit transaction." );
 
+    // Date time is always stored in UTC time zone by the server.
+    QString datetime = QLocale::c().toString( item.datetime(), QLatin1String( "dd-MMM-yyyy hh:mm:ss +0000" ) );
+
+    QByteArray res( "[UIDNEXT " + QByteArray::number( item.id() ) + " " );
+    res.append( "DATETIME " + ImapParser::quote( datetime.toUtf8() ) );
+    res.append( ']' );
+
     response.setTag( tag() );
     response.setUserDefined();
-    response.setString( "[UIDNEXT " + QByteArray::number( item.id() ) + ']' );
+    response.setString( res );
     emit responseAvailable( response );
 
     response.setSuccess();
