@@ -20,6 +20,7 @@
 #include "store.h"
 
 #include <QtCore/QStringList>
+#include <QLocale>
 
 #include "akonadi.h"
 #include "akonadiconnection.h"
@@ -72,18 +73,20 @@ bool Store::handleLine( const QByteArray& line )
     return failureResponse( "No items found" );
 
   // parse revision
-  qint64 rev;
-  bool revCheck = true;
+  qint64 rev = 0;
+  bool revCheck = false;
   bool ok;
   pos = ImapParser::parseString( line, buffer, pos ); // skip 'REV'
   if ( buffer == "REV" ) {
+    revCheck = true;
     pos = ImapParser::parseNumber( line, rev, &ok, pos );
     if ( !ok ) {
       return failureResponse( "Unable to parse item revision number." );
     }
   }
-  else if ( buffer == "NOREV" )
-    revCheck   = false;
+
+  // Set the same modification time for each item.
+  QDateTime modificationtime = QDateTime::currentDateTime().toUTC();
 
   for ( int i = 0; i < pimItems.count(); ++i ) {
     if ( revCheck ) {
@@ -95,12 +98,22 @@ bool Store::handleLine( const QByteArray& line )
 
     // update item revision
     pimItems[ i ].setRev( pimItems[ i ].rev() + 1 );
-    pimItems[ i ].setDatetime( QDateTime::currentDateTime() );
+    pimItems[ i ].setDatetime( modificationtime );
     if ( !pimItems[ i ].update() ) {
       return failureResponse( "Unable to update item revision" );
     }
   }
 
+  // parse size
+  qint64 size = 0;
+  pos = ImapParser::parseString( line, buffer, pos );
+  if ( buffer == "SIZE" ) {
+    pos = ImapParser::parseNumber( line, size, &ok, pos );
+    if ( !ok ) {
+      return failureResponse( "Unable to parse the size." + line);
+    }
+  }
+
   QList<QByteArray> changes;
   pos = ImapParser::parseParenthesizedList( line, changes, pos );
   for ( int i = 0; i < changes.size() - 1; i += 2 ) {
@@ -210,9 +223,11 @@ bool Store::handleLine( const QByteArray& line )
   if ( !transaction.commit() )
     return failureResponse( "Cannot commit transaction." );
 
+  QString datetime = QLocale::c().toString( modificationtime, QLatin1String( "dd-MMM-yyyy hh:mm:ss +0000" ) );
+
   response.setTag( tag() );
   response.setSuccess();
-  response.setString( "STORE completed" );
+  response.setString( "DATETIME " + ImapParser::quote( datetime.toUtf8() ) + " STORE completed" );
 
   emit responseAvailable( response );
   deleteLater();
