@@ -69,6 +69,8 @@ Host=localhost
 User=foo
 Password=*****
 #Options=UNIX_SOCKET=/home/foo/.local/share/akonadi/db_misc/mysql.socket
+StartServer=true
+ServerPath=/usr/sbin/mysqld
 
 [QSQLITE]
 Name=/home/foo/.local/share/akonadi/akonadi.db
@@ -91,6 +93,8 @@ Name=/home/foo/.local/share/akonadi/akonadi.db
   - User: Username for the database server
   - Password: Password for the database server
   - Options: Additional options, format is driver-dependent
+  - StartServer: Start the database locally just for Akonadi instead of using an existing one
+  - ServerPath: Path to the server executable
 */
 class AKONADIPRIVATE_EXPORT DataStore : public QObject
 {
@@ -191,8 +195,6 @@ class AKONADIPRIVATE_EXPORT DataStore : public QObject
      */
     qint64 uidNext() const;
 
-    QString storagePath() const;
-
     /**
       Begins a transaction. No changes will be written to the database and
       no notification signal will be emitted unless you call commitTransaction().
@@ -233,11 +235,6 @@ class AKONADIPRIVATE_EXPORT DataStore : public QObject
     */
     void setSessionId( const QByteArray &sessionId ) { mSessionId = sessionId; }
 
-    /**
-      Returns the name of the used database driver.
-    */
-    static QString driverName() { return mDbDriverName; }
-
 Q_SIGNALS:
     /**
       Emitted if a transaction has been successfully committed.
@@ -301,14 +298,6 @@ private:
     static QMutex mPendingItemDeliveriesMutex;
     static QWaitCondition mPendingItemDeliveriesCondition;
 
-    // database configuration
-    static QString mDbDriverName;
-    static QString mDbName;
-    static QString mDbHostName;
-    static QString mDbUserName;
-    static QString mDbPassword;
-    static QString mDbConnectionOptions;
-
     // resource dbus interface cache
     QHash<QString, org::freedesktop::Akonadi::Resource*> mResourceInterfaceCache;
 };
