@@ -20,7 +20,7 @@
 #ifndef AKONADI_NOTIFICATIONCOLLECTOR_H
 #define AKONADI_NOTIFICATIONCOLLECTOR_H
 
-#include <entities.h>
+#include "entities.h"
 
 #include "../../libs/notificationmessage_p.h"
 
@@ -96,6 +96,16 @@ class NotificationCollector : public QObject
                       const QString &mimeType = QString(),
                       const QByteArray &resource = QByteArray() );
 
+    /**
+     * Notify about a linked item.
+     */
+    void itemLinked( const PimItem &item, const Location &collection );
+
+    /**
+     * Notify about a unlinked item.
+     */
+    void itemUnlinked( const PimItem &item, const Location &collection );
+
     /**
       Notify about a added collection.
       Provide as many parameters as you have at hand currently, everything
